# health-menu
随机搭配健康餐菜单

[![org](https://img.shields.io/static/v1?style=for-the-badge&label=org&message=Assurance%20Sphere&color=ff582c)](https://will.bowxeon.com)
![License](https://img.shields.io/github/license/seoktaehyeon/health-menu?style=for-the-badge)
![author](https://img.shields.io/static/v1?style=for-the-badge&label=author&message=v.stone@163.com&color=blue)
[![Python](https://img.shields.io/static/v1?style=for-the-badge&logo=python&label=Python&message=3.8&color=306ba1)](https://docs.python.org/release/3.8.11/)
[![PyPI](https://img.shields.io/pypi/v/health-menu.svg?style=for-the-badge)](https://pypi.org/project/health-menu/)

## 背景

虽然各种健康 APP、做菜 APP、买菜 APP 很多，并且都做得很优秀，但对于一个厨盲来说，窜连起来很困难，以下3个痛点始终存在：

- 不知道吃什么
- 每天罗列菜单
- 规划采购

## 支持生成随机菜单并汇总采购清单

- 一日菜单 和 一日采购清单
- 一周菜单 和 一周采购清单
- 一个月菜单（30天）和一个月采购清单

## 如何使用（码农命令行）

#### 安装
```bash
pip install health-menu
```

#### 一日菜单
```bash
health-menu -d
```

#### 一周菜单
```bash
health-menu -w
```

#### 一个月菜单
```bash
health-menu -m
```

## 如何使用（浏览器访问）

#### 一天的菜单
https://will.bowxeon.com/health-menu/day

#### 一周的菜单
https://will.bowxeon.com/health-menu/week

#### 一个月的菜单
https://will.bowxeon.com/health-menu/month
